﻿using System.Collections.Generic;
using Android.App;
using Android.Content;
using Android.Graphics;
using Android.Views;
using Android.Widget;
using Android.OS;
using Com.Telerik.Widget.Calendar;
using Com.Telerik.Widget.Calendar.Events;
using Java.Util;

namespace CustomInlineEventRepro
{
    [Activity(Label = "CustomInlineEventRepro", MainLauncher = true, Icon = "@drawable/icon")]
    public class MainActivity : Activity
    {
        protected override void OnCreate(Bundle bundle)
        {
            base.OnCreate(bundle);

            // Set our view from the "main" layout resource
            SetContentView(Resource.Layout.Main);

            var calendarView = FindViewById<RadCalendarView>(Resource.Id.calendarView);
            calendarView.SelectionMode = CalendarSelectionMode.Single;
            calendarView.EventsDisplayMode = EventsDisplayMode.Inline;

            MyInlineEventsAdapter adapter = new MyInlineEventsAdapter(this);
            calendarView.EventsManager().Adapter = adapter;

            Calendar calendar = Calendar.Instance;
            calendar.Set(CalendarField.DayOfWeek, 2);
            calendar.Set(CalendarField.HourOfDay, 20);
            calendar.Set(CalendarField.Minute, 0);
            calendar.Set(CalendarField.Second, 0);
            calendar.Set(CalendarField.Millisecond, 0);
            calendar.Add(CalendarField.Hour, 3);

            long eventStart = calendar.TimeInMillis;
            long eventEnd = calendar.TimeInMillis;

            calendar.Set(CalendarField.DayOfWeek, 3);
            long breakfastStart = calendar.TimeInMillis;
            long breakfastEnd = calendar.TimeInMillis;

            List<Event> events = new List<Event>()
            {
                new Event("Dinner with Jane", eventStart, eventEnd),
                new Event("Breakfast with Jane", breakfastStart, breakfastEnd)
            };

            calendarView.EventAdapter.Events = events;
        }
    }

    public class MyInlineEventsAdapter : ArrayAdapter
    {
        private readonly LayoutInflater layoutInflater;

        public MyInlineEventsAdapter(Context context)
            : base(context, Resource.Layout.CustomInlineEventLayout)
        {
            this.layoutInflater = LayoutInflater.From(context); ;
        }

        public override View GetView(int position, View convertView, ViewGroup parent)
        {
            View view = convertView;
            ViewHolder holder;

            if (view == null)
            {
                view = layoutInflater.Inflate(
                    Resource.Layout.CustomInlineEventLayout, parent, false);

                holder = new ViewHolder();
                holder.eventTitle = (TextView)view.FindViewById(Resource.Id.event_title);
                holder.eventTime = (TextView)view.FindViewById(Resource.Id.event_time);

                view.Tag = holder;
            }
            else
            {
                holder = (ViewHolder)view.Tag;
            }

            EventsManager.EventInfo eventInfo = (EventsManager.EventInfo)GetItem(position);
            Event event1 = eventInfo.OriginalEvent();
            holder.eventTitle.SetTextColor(new Color(event1.EventColor));
            holder.eventTitle.Text = event1.Title;
            string eventTime = $"{eventInfo.StartTimeFormatted()} - {eventInfo.EndTimeFormatted()}";
            holder.eventTime.Text = eventTime;

            return view;
        }

        class ViewHolder : Java.Lang.Object
        {
            public TextView eventTitle;
            public TextView eventTime;
        }
    }
}

